@@ -5,12 +5,13 @@ import pickle
 def save_numpickle(df, outfpath):
     arr, colnames, rownames = df.to_numpy(), df.columns, df.index
     np.save(arr=arr, file=outfpath)
-    pickle.dump({'colnames': colnames, 'rownames': rownames}, 
+    pickle.dump({'colnames': colnames, 'rownames': rownames, 'dtypes': df.dtypes}, 
                 open(outfpath + ".pckl", "wb"))
 
 def load_numpickle(fpath):
-    df = pd.DataFrame(np.load(fpath))
+    df = pd.DataFrame(np.load(fpath, allow_pickle=True))
     with open(fpath + ".pckl", "rb") as fin:
         meta = pickle.load(fin)
-    df.index, df.columns = meta['rownames'], meta['colnames']
+    df.index, df.columns, dtypes = meta['rownames'], meta['colnames'], meta['dtypes']
+    df = df.astype(dtypes)
     return df
